part of example.basic_auth.server;

/// This route group contains login and logout routes
@Api()
class AuthRoutes extends Object with JsonRoutes {
  JsonRepo get repo => jsonRepo;

  @Post(path: '/login')
  @WrapOne(#jsonAuth)
  Response<String> login(Context ctx) {
    final User user = ctx.getInput<User>(JsonAuth);
    return toJson(user);
  }

  @Post(path: '/logout')
  Future logout(Context ctx) async {
    // Clear session data
    (await ctx.req.session).clear();
  }

  /// The authenticator
  JsonAuth jsonAuth(Context ctx) => new JsonAuth(kModelManager);
}

/// Collection of routes students can also access
@Api(path: '/book')
class StudentRoutes extends Object with JsonRoutes {
  JsonRepo get repo => jsonRepo;

  @Get()
  Response<String> getAllBooks(Context ctx) {
    // Authorize. Throws 401 http error, if authorization fails!
    Authorizer.authorize(ctx, kModelManager);

    return toJson(_books.values);
  }

  @Get(path: '/:id')
  Response<String> getBook(Context ctx) {
    // Authorize. Throws 401 http error, if authorization fails!
    Authorizer.authorize(ctx, kModelManager);

    String id = ctx.pathParams.get('id');
    Book book = _books[id];
    return toJson(book);
  }
}
